@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Univention Samba
 #  listener module: manages samba privileges
@@ -35,7 +34,7 @@
 
 from __future__ import annotations
 
-from typing import Dict, Iterable, List
+from typing import TYPE_CHECKING
 
 import tdb
 
@@ -44,6 +43,10 @@ import univention.debug as ud
 from listener import SetUID
 
 
+if TYPE_CHECKING:
+    from collections.abc import Iterable
+
+
 SAMBA_PRIVILEGES = {
     b"SeMachineAccountPrivilege": {"number": 16, "index": 0},
     b"SeAddUsersPrivilege": {"number": 64, "index": 0},
@@ -66,7 +69,7 @@ filter = '(&(objectClass=univentionSambaPrivileges)(sambaSID=*))'
 atributes = ['univentionSambaPrivilegeList', 'sambaSID']
 
 
-def handler(dn: str, new: Dict[str, List[bytes]], old: Dict[str, List[bytes]]) -> None:
+def handler(dn: str, new: dict[str, list[bytes]], old: dict[str, list[bytes]]) -> None:
 
     where = ud.LISTENER
     level = ud.INFO
